Control Mechanisms
==================

.. _ControlMechanism_Subtypes:

.. toctree::
   :maxdepth: 1

   GatingMechanism <GatingMechanism>
   OptimzationControlMechanism <OptimizationControlMechanism>

.. automodule:: psyneulink.core.components.mechanisms.modulatory.control.controlmechanism
   :members:
   :exclude-members: Linear, random, Parameters
